@@ -1,7 +1,7 @@
 /*
  * Seahorse
  *
- * Copyright (C) 2004 - 2006 Nate Nielsen
+ * Copyright (C) 2004 - 2006 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -273,18 +273,22 @@ get_algo_attribute (LDAP* ld, LDAPMessage *res, const char *attribute)
     return a;
 }
 
-/* Escapes a value so it's safe to use in an LDAP filter */
+/* 
+ * Escapes a value so it's safe to use in an LDAP filter. Also trims
+ * any spaces which cause problems with some LDAP servers.
+ */
 static gchar*
 escape_ldap_value (const gchar *v)
 {
     GString *value;
+    gchar* result;
     
     g_assert (v);
     value = g_string_sized_new (strlen(v));
     
     for ( ; *v; v++) {
         switch(*v) {
-        case ' ': case '#': case ',': case '+': case '\\':
+        case '#': case ',': case '+': case '\\':
         case '/': case '\"': case '<': case '>': case ';':
             value = g_string_append_c (value, '\\');
             value = g_string_append_c (value, *v);
@@ -299,7 +303,9 @@ escape_ldap_value (const gchar *v)
         value = g_string_append_c (value, *v);
     }
     
-    return g_string_free (value, FALSE);
+    result = g_string_free (value, FALSE);
+    g_strstrip (result);
+    return result;
 }
 
 /* -----------------------------------------------------------------------------
@@ -648,7 +654,7 @@ resolved_callback (gpointer unused, guint status, SeahorseLDAPOperation *lop)
     /* The ldap_cb and chain_cb were set in seahorse_ldap_operation_start */
     
     t = g_strdup_printf (_("Connecting to: %s"), server);
-    seahorse_operation_mark_progress (SEAHORSE_OPERATION (lop), t, 0.0);
+    seahorse_operation_mark_progress (SEAHORSE_OPERATION (lop), t, -1);
     g_free (t);
 
     g_free (server);
@@ -697,7 +703,7 @@ seahorse_ldap_operation_start (SeahorseLDAPSource *lsrc, OpLDAPCallback cb,
     lop->addr = soup_address_new (server, LDAP_PORT);
     
     t = g_strdup_printf (_("Resolving server address: %s"), server);
-    seahorse_operation_mark_progress (SEAHORSE_OPERATION (lop), t, 0.0);
+    seahorse_operation_mark_progress (SEAHORSE_OPERATION (lop), t, -1);
     g_free (t);
 
     g_free (server);
@@ -836,9 +842,13 @@ start_search (SeahorseOperation *op, LDAPMessage *result)
     g_return_val_if_fail (filter != NULL, FALSE);
 
     t = (gchar*)g_object_get_data (G_OBJECT (lop), "details");
-    seahorse_operation_mark_progress (SEAHORSE_OPERATION (lop), t, 0.0);
+    seahorse_operation_mark_progress (SEAHORSE_OPERATION (lop), t, -1);
     
     sinfo = get_ldap_server_info (lop->lsrc, TRUE);
+
+    DEBUG_LDAP (("[ldap] Searching Server ... base: %s, filter: %s\n", 
+                 sinfo->base_dn, filter));
+    
     r = ldap_search_ext (lop->ldap, sinfo->base_dn, LDAP_SCOPE_SUBTREE,
                          filter, (char**)kPGPAttributes, 0,
                          NULL, NULL, NULL, 0, &(lop->ldap_op));    
