@@ -1,7 +1,7 @@
 /*
  * Seahorse
  *
- * Copyright (C) 2006 Nate Nielsen
+ * Copyright (C) 2006 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -65,18 +65,18 @@ choose_keytype(SeahorseWidget *swidget)
     sksrc = seahorse_context_find_key_source (SCTX_APP (), ktype, SKEY_LOC_LOCAL);
     g_return_if_fail (sksrc != NULL);
     
-    seahorse_widget_destroy (swidget);
-    
     if (ktype == SKEY_PGP)
-        seahorse_pgp_generate_show (SEAHORSE_PGP_SOURCE (sksrc));
+        seahorse_pgp_generate_show (SEAHORSE_PGP_SOURCE (sksrc), GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
         
 #ifdef WITH_SSH 
     else if (ktype == SKEY_SSH)
-        seahorse_ssh_generate_show (SEAHORSE_SSH_SOURCE (sksrc));
+        seahorse_ssh_generate_show (SEAHORSE_SSH_SOURCE (sksrc), GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
 #endif 
     
     else
         g_return_if_reached ();
+
+    seahorse_widget_destroy (swidget);
 }
 
 static void
@@ -119,7 +119,7 @@ add_key_type (GtkListStore *store, GQuark type, const char *stock_icon,
 }
 
 void
-seahorse_generate_select_show ()
+seahorse_generate_select_show (GtkWindow *parent)
 {
     SeahorseWidget *swidget;
     GtkListStore *store;
@@ -128,7 +128,7 @@ seahorse_generate_select_show ()
     GtkTreeIter iter;
     GtkWidget *widget;
     
-    swidget = seahorse_widget_new ("generate-select");
+    swidget = seahorse_widget_new ("generate-select", parent);
     
     /* Widget already exists */
     if (swidget == NULL)
